# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bilibili/app/interfaces/v1/search.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'bilibili/app/interfaces/v1/search.proto\x12\x1a\x62ilibili.app.interfaces.v1\"R\n\x14SuggestionResult3Req\x12\x0f\n\x07keyword\x18\x01 \x01(\t\x12\x11\n\thighlight\x18\x02 \x01(\x05\x12\x16\n\x0eteenagers_mode\x18\x03 \x01(\x05\"o\n\x16SuggestionResult3Reply\x12\x0f\n\x07trackid\x18\x01 \x01(\t\x12\x34\n\x04list\x18\x02 \x03(\x0b\x32&.bilibili.app.interfaces.v1.ResultItem\x12\x0e\n\x06\x65xpStr\x18\x03 \x01(\t\"\xa1\x04\n\nResultItem\x12\x0c\n\x04\x66rom\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\x0f\n\x07keyword\x18\x03 \x01(\t\x12\x10\n\x08position\x18\x04 \x01(\x05\x12\r\n\x05\x63over\x18\x05 \x01(\t\x12\x12\n\ncover_size\x18\x06 \x01(\x01\x12\x10\n\x08sug_type\x18\x07 \x01(\t\x12\x11\n\tterm_type\x18\x08 \x01(\x05\x12\x0c\n\x04goto\x18\t \x01(\t\x12\x0b\n\x03uri\x18\n \x01(\t\x12\x43\n\x0fofficial_verify\x18\x0b \x01(\x0b\x32*.bilibili.app.interfaces.v1.OfficialVerify\x12\r\n\x05param\x18\x0c \x01(\t\x12\x0b\n\x03mid\x18\r \x01(\x03\x12\x0c\n\x04\x66\x61ns\x18\x0e \x01(\x05\x12\r\n\x05level\x18\x0f \x01(\x05\x12\x10\n\x08\x61rchives\x18\x10 \x01(\x05\x12\r\n\x05ptime\x18\x11 \x01(\x03\x12\x18\n\x10season_type_name\x18\x12 \x01(\t\x12\x0c\n\x04\x61rea\x18\x13 \x01(\t\x12\r\n\x05style\x18\x14 \x01(\t\x12\r\n\x05label\x18\x15 \x01(\t\x12\x0e\n\x06rating\x18\x16 \x01(\x01\x12\x0c\n\x04vote\x18\x17 \x01(\x05\x12\x37\n\x06\x62\x61\x64ges\x18\x18 \x03(\x0b\x32\'.bilibili.app.interfaces.v1.ReasonStyle\x12\x0e\n\x06styles\x18\x19 \x01(\t\x12\x11\n\tmodule_id\x18\x1a \x01(\x03\x12\x11\n\tlive_link\x18\x1b \x01(\t\",\n\x0eOfficialVerify\x12\x0c\n\x04type\x18\x01 \x01(\x05\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\t\"\xb7\x01\n\x0bReasonStyle\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x12\n\ntext_color\x18\x02 \x01(\t\x12\x18\n\x10text_color_night\x18\x03 \x01(\t\x12\x10\n\x08\x62g_color\x18\x04 \x01(\t\x12\x16\n\x0e\x62g_color_night\x18\x05 \x01(\t\x12\x14\n\x0c\x62order_color\x18\x06 \x01(\t\x12\x1a\n\x12\x62order_color_night\x18\x07 \x01(\t\x12\x10\n\x08\x62g_style\x18\x08 \x01(\x05\x32z\n\x06Search\x12p\n\x08Suggest3\x12\x30.bilibili.app.interfaces.v1.SuggestionResult3Req\x1a\x32.bilibili.app.interfaces.v1.SuggestionResult3Replyb\x06proto3')



_SUGGESTIONRESULT3REQ = DESCRIPTOR.message_types_by_name['SuggestionResult3Req']
_SUGGESTIONRESULT3REPLY = DESCRIPTOR.message_types_by_name['SuggestionResult3Reply']
_RESULTITEM = DESCRIPTOR.message_types_by_name['ResultItem']
_OFFICIALVERIFY = DESCRIPTOR.message_types_by_name['OfficialVerify']
_REASONSTYLE = DESCRIPTOR.message_types_by_name['ReasonStyle']
SuggestionResult3Req = _reflection.GeneratedProtocolMessageType('SuggestionResult3Req', (_message.Message,), {
  'DESCRIPTOR' : _SUGGESTIONRESULT3REQ,
  '__module__' : 'bilibili.app.interfaces.v1.search_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.interfaces.v1.SuggestionResult3Req)
  })
_sym_db.RegisterMessage(SuggestionResult3Req)

SuggestionResult3Reply = _reflection.GeneratedProtocolMessageType('SuggestionResult3Reply', (_message.Message,), {
  'DESCRIPTOR' : _SUGGESTIONRESULT3REPLY,
  '__module__' : 'bilibili.app.interfaces.v1.search_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.interfaces.v1.SuggestionResult3Reply)
  })
_sym_db.RegisterMessage(SuggestionResult3Reply)

ResultItem = _reflection.GeneratedProtocolMessageType('ResultItem', (_message.Message,), {
  'DESCRIPTOR' : _RESULTITEM,
  '__module__' : 'bilibili.app.interfaces.v1.search_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.interfaces.v1.ResultItem)
  })
_sym_db.RegisterMessage(ResultItem)

OfficialVerify = _reflection.GeneratedProtocolMessageType('OfficialVerify', (_message.Message,), {
  'DESCRIPTOR' : _OFFICIALVERIFY,
  '__module__' : 'bilibili.app.interfaces.v1.search_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.interfaces.v1.OfficialVerify)
  })
_sym_db.RegisterMessage(OfficialVerify)

ReasonStyle = _reflection.GeneratedProtocolMessageType('ReasonStyle', (_message.Message,), {
  'DESCRIPTOR' : _REASONSTYLE,
  '__module__' : 'bilibili.app.interfaces.v1.search_pb2'
  # @@protoc_insertion_point(class_scope:bilibili.app.interfaces.v1.ReasonStyle)
  })
_sym_db.RegisterMessage(ReasonStyle)

_SEARCH = DESCRIPTOR.services_by_name['Search']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SUGGESTIONRESULT3REQ._serialized_start=71
  _SUGGESTIONRESULT3REQ._serialized_end=153
  _SUGGESTIONRESULT3REPLY._serialized_start=155
  _SUGGESTIONRESULT3REPLY._serialized_end=266
  _RESULTITEM._serialized_start=269
  _RESULTITEM._serialized_end=814
  _OFFICIALVERIFY._serialized_start=816
  _OFFICIALVERIFY._serialized_end=860
  _REASONSTYLE._serialized_start=863
  _REASONSTYLE._serialized_end=1046
  _SEARCH._serialized_start=1048
  _SEARCH._serialized_end=1170
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.any_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _DetailListScene:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _DetailListSceneEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DetailListScene.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    REPLY: _DetailListScene.ValueType  # 0
    """评论区展开"""

    MSG_FEED: _DetailListScene.ValueType  # 1
    """回复消息推送"""

    NOTIFY: _DetailListScene.ValueType  # 2
    """"""

class DetailListScene(_DetailListScene, metaclass=_DetailListSceneEnumTypeWrapper):
    """来源标识"""
    pass

REPLY: DetailListScene.ValueType  # 0
"""评论区展开"""

MSG_FEED: DetailListScene.ValueType  # 1
"""回复消息推送"""

NOTIFY: DetailListScene.ValueType  # 2
""""""

global___DetailListScene = DetailListScene


class _Mode:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _ModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Mode.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    DEFAULT: _Mode.ValueType  # 0
    """"""

    UNSPECIFIED: _Mode.ValueType  # 1
    """默认排序"""

    MAIN_LIST_TIME: _Mode.ValueType  # 2
    """按时间"""

    MAIN_LIST_HOT: _Mode.ValueType  # 3
    """按热度"""

class Mode(_Mode, metaclass=_ModeEnumTypeWrapper):
    """排序方式"""
    pass

DEFAULT: Mode.ValueType  # 0
""""""

UNSPECIFIED: Mode.ValueType  # 1
"""默认排序"""

MAIN_LIST_TIME: Mode.ValueType  # 2
"""按时间"""

MAIN_LIST_HOT: Mode.ValueType  # 3
"""按热度"""

global___Mode = Mode


class _SearchItemType:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _SearchItemTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_SearchItemType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    DEFAULT_ITEM_TYPE: _SearchItemType.ValueType  # 0
    """"""

    GOODS: _SearchItemType.ValueType  # 1
    """"""

    VIDEO: _SearchItemType.ValueType  # 2
    """"""

    ARTICLE: _SearchItemType.ValueType  # 3
    """"""

class SearchItemType(_SearchItemType, metaclass=_SearchItemTypeEnumTypeWrapper):
    """"""
    pass

DEFAULT_ITEM_TYPE: SearchItemType.ValueType  # 0
""""""

GOODS: SearchItemType.ValueType  # 1
""""""

VIDEO: SearchItemType.ValueType  # 2
""""""

ARTICLE: SearchItemType.ValueType  # 3
""""""

global___SearchItemType = SearchItemType


class _SearchItemVideoSubType:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _SearchItemVideoSubTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_SearchItemVideoSubType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UGC: _SearchItemVideoSubType.ValueType  # 0
    """"""

    PGC: _SearchItemVideoSubType.ValueType  # 1
    """"""

class SearchItemVideoSubType(_SearchItemVideoSubType, metaclass=_SearchItemVideoSubTypeEnumTypeWrapper):
    """"""
    pass

UGC: SearchItemVideoSubType.ValueType  # 0
""""""

PGC: SearchItemVideoSubType.ValueType  # 1
""""""

global___SearchItemVideoSubType = SearchItemVideoSubType


class _UserCallbackAction:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _UserCallbackActionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_UserCallbackAction.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    Dismiss: _UserCallbackAction.ValueType  # 0
    """"""

class UserCallbackAction(_UserCallbackAction, metaclass=_UserCallbackActionEnumTypeWrapper):
    """"""
    pass

Dismiss: UserCallbackAction.ValueType  # 0
""""""

global___UserCallbackAction = UserCallbackAction


class _UserCallbackScene:
    ValueType = typing.NewType('ValueType', builtins.int)
    V: typing_extensions.TypeAlias = ValueType
class _UserCallbackSceneEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_UserCallbackScene.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    Insert: _UserCallbackScene.ValueType  # 0
    """"""

class UserCallbackScene(_UserCallbackScene, metaclass=_UserCallbackSceneEnumTypeWrapper):
    """"""
    pass

Insert: UserCallbackScene.ValueType  # 0
""""""

global___UserCallbackScene = UserCallbackScene


class Activity(google.protobuf.message.Message):
    """活动"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ACTIVITY_ID_FIELD_NUMBER: builtins.int
    ACTIVITY_STATE_FIELD_NUMBER: builtins.int
    ACTIVITY_PLACEHOLDER_FIELD_NUMBER: builtins.int
    activity_id: builtins.int
    """活动id"""

    activity_state: builtins.int
    """活动状态
    -1:待审 1:上线
    """

    activity_placeholder: typing.Text
    """参与活动的输入框文案"""

    def __init__(self,
        *,
        activity_id: builtins.int = ...,
        activity_state: builtins.int = ...,
        activity_placeholder: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["activity_id",b"activity_id","activity_placeholder",b"activity_placeholder","activity_state",b"activity_state"]) -> None: ...
global___Activity = Activity

class ArticleSearchItem(google.protobuf.message.Message):
    """文章项目"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TITLE_FIELD_NUMBER: builtins.int
    UP_NICKNAME_FIELD_NUMBER: builtins.int
    COVERS_FIELD_NUMBER: builtins.int
    title: typing.Text
    """标题"""

    up_nickname: typing.Text
    """UP主昵称"""

    @property
    def covers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[typing.Text]:
        """封面"""
        pass
    def __init__(self,
        *,
        title: typing.Text = ...,
        up_nickname: typing.Text = ...,
        covers: typing.Optional[typing.Iterable[typing.Text]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["covers",b"covers","title",b"title","up_nickname",b"up_nickname"]) -> None: ...
global___ArticleSearchItem = ArticleSearchItem

class AtGroup(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    GROUP_TYPE_FIELD_NUMBER: builtins.int
    GROUP_NAME_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    group_type: builtins.int
    """"""

    group_name: typing.Text
    """"""

    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AtItem]:
        """"""
        pass
    def __init__(self,
        *,
        group_type: builtins.int = ...,
        group_name: typing.Text = ...,
        items: typing.Optional[typing.Iterable[global___AtItem]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["group_name",b"group_name","group_type",b"group_type","items",b"items"]) -> None: ...
global___AtGroup = AtGroup

class AtItem(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    FACE_FIELD_NUMBER: builtins.int
    FANS_FIELD_NUMBER: builtins.int
    OFFICIAL_VERIFY_TYPE_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""

    name: typing.Text
    """"""

    face: typing.Text
    """"""

    fans: builtins.int
    """"""

    official_verify_type: builtins.int
    """"""

    def __init__(self,
        *,
        mid: builtins.int = ...,
        name: typing.Text = ...,
        face: typing.Text = ...,
        fans: builtins.int = ...,
        official_verify_type: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["face",b"face","fans",b"fans","mid",b"mid","name",b"name","official_verify_type",b"official_verify_type"]) -> None: ...
global___AtItem = AtItem

class AtSearchReply(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    GROUPS_FIELD_NUMBER: builtins.int
    @property
    def groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AtGroup]:
        """"""
        pass
    def __init__(self,
        *,
        groups: typing.Optional[typing.Iterable[global___AtGroup]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["groups",b"groups"]) -> None: ...
global___AtSearchReply = AtSearchReply

class AtSearchReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MID_FIELD_NUMBER: builtins.int
    KEYWORD_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""

    keyword: typing.Text
    """"""

    def __init__(self,
        *,
        mid: builtins.int = ...,
        keyword: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["keyword",b"keyword","mid",b"mid"]) -> None: ...
global___AtSearchReq = AtSearchReq

class CM(google.protobuf.message.Message):
    """广告"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SOURCE_CONTENT_FIELD_NUMBER: builtins.int
    @property
    def source_content(self) -> google.protobuf.any_pb2.Any:
        """广告数据(需要解包)"""
        pass
    def __init__(self,
        *,
        source_content: typing.Optional[google.protobuf.any_pb2.Any] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["source_content",b"source_content"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["source_content",b"source_content"]) -> None: ...
global___CM = CM

class Content(google.protobuf.message.Message):
    """评论主体信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class MenberEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: typing.Text
        @property
        def value(self) -> global___Member: ...
        def __init__(self,
            *,
            key: typing.Text = ...,
            value: typing.Optional[global___Member] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value",b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key",b"key","value",b"value"]) -> None: ...

    class EmoteEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: typing.Text
        @property
        def value(self) -> global___Emote: ...
        def __init__(self,
            *,
            key: typing.Text = ...,
            value: typing.Optional[global___Emote] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value",b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key",b"key","value",b"value"]) -> None: ...

    class TopicEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: typing.Text
        @property
        def value(self) -> global___Topic: ...
        def __init__(self,
            *,
            key: typing.Text = ...,
            value: typing.Optional[global___Topic] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value",b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key",b"key","value",b"value"]) -> None: ...

    class UrlEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: typing.Text
        @property
        def value(self) -> global___Url: ...
        def __init__(self,
            *,
            key: typing.Text = ...,
            value: typing.Optional[global___Url] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["value",b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["key",b"key","value",b"value"]) -> None: ...

    MESSAGE_FIELD_NUMBER: builtins.int
    MENBER_FIELD_NUMBER: builtins.int
    EMOTE_FIELD_NUMBER: builtins.int
    TOPIC_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    VOTE_FIELD_NUMBER: builtins.int
    message: typing.Text
    """评论文本"""

    @property
    def menber(self) -> google.protobuf.internal.containers.MessageMap[typing.Text, global___Member]:
        """at到的用户信息"""
        pass
    @property
    def emote(self) -> google.protobuf.internal.containers.MessageMap[typing.Text, global___Emote]:
        """需要渲染的表情转义"""
        pass
    @property
    def topic(self) -> google.protobuf.internal.containers.MessageMap[typing.Text, global___Topic]:
        """需要高亮的话题转义"""
        pass
    @property
    def url(self) -> google.protobuf.internal.containers.MessageMap[typing.Text, global___Url]:
        """需要高亮的超链转义"""
        pass
    @property
    def vote(self) -> global___Vote:
        """投票信息"""
        pass
    def __init__(self,
        *,
        message: typing.Text = ...,
        menber: typing.Optional[typing.Mapping[typing.Text, global___Member]] = ...,
        emote: typing.Optional[typing.Mapping[typing.Text, global___Emote]] = ...,
        topic: typing.Optional[typing.Mapping[typing.Text, global___Topic]] = ...,
        url: typing.Optional[typing.Mapping[typing.Text, global___Url]] = ...,
        vote: typing.Optional[global___Vote] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["vote",b"vote"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["emote",b"emote","menber",b"menber","message",b"message","topic",b"topic","url",b"url","vote",b"vote"]) -> None: ...
global___Content = Content

class CursorReply(google.protobuf.message.Message):
    """页面游标回复"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    NEXT_FIELD_NUMBER: builtins.int
    PREV_FIELD_NUMBER: builtins.int
    ISBEGIN_FIELD_NUMBER: builtins.int
    ISEND_FIELD_NUMBER: builtins.int
    MODE_FIELD_NUMBER: builtins.int
    MODE_TEXT_FIELD_NUMBER: builtins.int
    next: builtins.int
    """下页数据"""

    prev: builtins.int
    """上页数据"""

    isBegin: builtins.bool
    """是否到顶"""

    isEnd: builtins.bool
    """是否到底"""

    mode: global___Mode.ValueType
    """排序方式
    2:时间 3:热度
    """

    mode_text: typing.Text
    """当前排序mode在切换按钮上的展示文案"""

    def __init__(self,
        *,
        next: builtins.int = ...,
        prev: builtins.int = ...,
        isBegin: builtins.bool = ...,
        isEnd: builtins.bool = ...,
        mode: global___Mode.ValueType = ...,
        mode_text: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["isBegin",b"isBegin","isEnd",b"isEnd","mode",b"mode","mode_text",b"mode_text","next",b"next","prev",b"prev"]) -> None: ...
global___CursorReply = CursorReply

class CursorReq(google.protobuf.message.Message):
    """页面游标请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    NEXT_FIELD_NUMBER: builtins.int
    PREV_FIELD_NUMBER: builtins.int
    MODE_FIELD_NUMBER: builtins.int
    next: builtins.int
    """下页数据"""

    prev: builtins.int
    """上页数据"""

    mode: global___Mode.ValueType
    """排序方式"""

    def __init__(self,
        *,
        next: builtins.int = ...,
        prev: builtins.int = ...,
        mode: global___Mode.ValueType = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["mode",b"mode","next",b"next","prev",b"prev"]) -> None: ...
global___CursorReq = CursorReq

class DetailListReply(google.protobuf.message.Message):
    """二级评论明细-响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CURSOR_FIELD_NUMBER: builtins.int
    SUBJECT_CONTROL_FIELD_NUMBER: builtins.int
    ROOT_FIELD_NUMBER: builtins.int
    ACTIVITY_FIELD_NUMBER: builtins.int
    LIKES_FIELD_NUMBER: builtins.int
    @property
    def cursor(self) -> global___CursorReply:
        """页面游标"""
        pass
    @property
    def subject_control(self) -> global___SubjectControl:
        """评论区显示控制字段"""
        pass
    @property
    def root(self) -> global___ReplyInfo:
        """根评论信息(带二级评论)"""
        pass
    @property
    def activity(self) -> global___Activity:
        """评论区的活动"""
        pass
    @property
    def likes(self) -> global___LikeInfo:
        """"""
        pass
    def __init__(self,
        *,
        cursor: typing.Optional[global___CursorReply] = ...,
        subject_control: typing.Optional[global___SubjectControl] = ...,
        root: typing.Optional[global___ReplyInfo] = ...,
        activity: typing.Optional[global___Activity] = ...,
        likes: typing.Optional[global___LikeInfo] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["activity",b"activity","cursor",b"cursor","likes",b"likes","root",b"root","subject_control",b"subject_control"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["activity",b"activity","cursor",b"cursor","likes",b"likes","root",b"root","subject_control",b"subject_control"]) -> None: ...
global___DetailListReply = DetailListReply

class DetailListReq(google.protobuf.message.Message):
    """二级评论明细-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    OID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    ROOT_FIELD_NUMBER: builtins.int
    RPID_FIELD_NUMBER: builtins.int
    CURSOR_FIELD_NUMBER: builtins.int
    SCENE_FIELD_NUMBER: builtins.int
    oid: builtins.int
    """目标评论区id"""

    type: builtins.int
    """目标评论区类型"""

    root: builtins.int
    """根评论rpid"""

    rpid: builtins.int
    """目标评论rpid"""

    @property
    def cursor(self) -> global___CursorReq:
        """页面游标"""
        pass
    scene: global___DetailListScene.ValueType
    """来源标识"""

    def __init__(self,
        *,
        oid: builtins.int = ...,
        type: builtins.int = ...,
        root: builtins.int = ...,
        rpid: builtins.int = ...,
        cursor: typing.Optional[global___CursorReq] = ...,
        scene: global___DetailListScene.ValueType = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cursor",b"cursor"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cursor",b"cursor","oid",b"oid","root",b"root","rpid",b"rpid","scene",b"scene","type",b"type"]) -> None: ...
global___DetailListReq = DetailListReq

class DialogListReply(google.protobuf.message.Message):
    """对话评论树-响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CURSOR_FIELD_NUMBER: builtins.int
    SUBJECT_CONTROL_FIELD_NUMBER: builtins.int
    REPLIES_FIELD_NUMBER: builtins.int
    ACTIVITY_FIELD_NUMBER: builtins.int
    @property
    def cursor(self) -> global___CursorReply:
        """页面游标"""
        pass
    @property
    def subject_control(self) -> global___SubjectControl:
        """评论区显示控制字段"""
        pass
    @property
    def replies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ReplyInfo]:
        """子评论列表"""
        pass
    @property
    def activity(self) -> global___Activity:
        """评论区的活动"""
        pass
    def __init__(self,
        *,
        cursor: typing.Optional[global___CursorReply] = ...,
        subject_control: typing.Optional[global___SubjectControl] = ...,
        replies: typing.Optional[typing.Iterable[global___ReplyInfo]] = ...,
        activity: typing.Optional[global___Activity] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["activity",b"activity","cursor",b"cursor","subject_control",b"subject_control"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["activity",b"activity","cursor",b"cursor","replies",b"replies","subject_control",b"subject_control"]) -> None: ...
global___DialogListReply = DialogListReply

class DialogListReq(google.protobuf.message.Message):
    """对话评论树-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    OID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    ROOT_FIELD_NUMBER: builtins.int
    RPID_FIELD_NUMBER: builtins.int
    CURSOR_FIELD_NUMBER: builtins.int
    oid: builtins.int
    """目标评论区id"""

    type: builtins.int
    """目标评论区类型"""

    root: builtins.int
    """根评论rpid"""

    rpid: builtins.int
    """对话评论rpid"""

    @property
    def cursor(self) -> global___CursorReq:
        """页面游标"""
        pass
    def __init__(self,
        *,
        oid: builtins.int = ...,
        type: builtins.int = ...,
        root: builtins.int = ...,
        rpid: builtins.int = ...,
        cursor: typing.Optional[global___CursorReq] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cursor",b"cursor"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cursor",b"cursor","oid",b"oid","root",b"root","rpid",b"rpid","type",b"type"]) -> None: ...
global___DialogListReq = DialogListReq

class Effects(google.protobuf.message.Message):
    """特效"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PRELOADING_FIELD_NUMBER: builtins.int
    preloading: typing.Text
    """"""

    def __init__(self,
        *,
        preloading: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["preloading",b"preloading"]) -> None: ...
global___Effects = Effects

class Emote(google.protobuf.message.Message):
    """表情项"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SIZE_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    JUMP_URL_FIELD_NUMBER: builtins.int
    JUMP_TITLE_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    PACKAGE_ID_FIELD_NUMBER: builtins.int
    GIF_URL_FIELD_NUMBER: builtins.int
    size: builtins.int
    """表情大小
    1:小 2:大
    """

    url: typing.Text
    """表情url"""

    jump_url: typing.Text
    """"""

    jump_title: typing.Text
    """"""

    id: builtins.int
    """"""

    package_id: builtins.int
    """"""

    gif_url: typing.Text
    """"""

    def __init__(self,
        *,
        size: builtins.int = ...,
        url: typing.Text = ...,
        jump_url: typing.Text = ...,
        jump_title: typing.Text = ...,
        id: builtins.int = ...,
        package_id: builtins.int = ...,
        gif_url: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["gif_url",b"gif_url","id",b"id","jump_title",b"jump_title","jump_url",b"jump_url","package_id",b"package_id","size",b"size","url",b"url"]) -> None: ...
global___Emote = Emote

class GoodsSearchItem(google.protobuf.message.Message):
    """商品项目"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PRICE_FIELD_NUMBER: builtins.int
    INCOME_FIELD_NUMBER: builtins.int
    IMG_FIELD_NUMBER: builtins.int
    LABEL_FIELD_NUMBER: builtins.int
    id: builtins.int
    """商品id"""

    name: typing.Text
    """商品名"""

    price: typing.Text
    """价钱"""

    income: typing.Text
    """收入"""

    img: typing.Text
    """图片"""

    label: typing.Text
    """标签"""

    def __init__(self,
        *,
        id: builtins.int = ...,
        name: typing.Text = ...,
        price: typing.Text = ...,
        income: typing.Text = ...,
        img: typing.Text = ...,
        label: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id",b"id","img",b"img","income",b"income","label",b"label","name",b"name","price",b"price"]) -> None: ...
global___GoodsSearchItem = GoodsSearchItem

class LikeInfo(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class Item(google.protobuf.message.Message):
        """"""
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        MEMBER_FIELD_NUMBER: builtins.int
        @property
        def member(self) -> global___Member:
            """"""
            pass
        def __init__(self,
            *,
            member: typing.Optional[global___Member] = ...,
            ) -> None: ...
        def HasField(self, field_name: typing_extensions.Literal["member",b"member"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing_extensions.Literal["member",b"member"]) -> None: ...

    ITEMS_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LikeInfo.Item]:
        """"""
        pass
    title: typing.Text
    """"""

    def __init__(self,
        *,
        items: typing.Optional[typing.Iterable[global___LikeInfo.Item]] = ...,
        title: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["items",b"items","title",b"title"]) -> None: ...
global___LikeInfo = LikeInfo

class Lottery(google.protobuf.message.Message):
    """抽奖"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    LOTTERY_ID_FIELD_NUMBER: builtins.int
    LOTTERY_STATUS_FIELD_NUMBER: builtins.int
    LOTTERY_MID_FIELD_NUMBER: builtins.int
    LOTTERY_TIME_FIELD_NUMBER: builtins.int
    OID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    CTIME_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    REPLY_CONTROL_FIELD_NUMBER: builtins.int
    lottery_id: builtins.int
    """抽奖id"""

    lottery_status: builtins.int
    """抽奖状态
    0:未开奖 1:开奖中 2:已开奖
    """

    lottery_mid: builtins.int
    """抽奖人mid"""

    lottery_time: builtins.int
    """开奖时间"""

    oid: builtins.int
    """"""

    type: builtins.int
    """"""

    ctime: builtins.int
    """发送时间"""

    @property
    def content(self) -> global___Content:
        """抽奖评论正文"""
        pass
    @property
    def member(self) -> global___Member:
        """用户信息"""
        pass
    @property
    def reply_control(self) -> global___ReplyControl:
        """评论条目控制字段"""
        pass
    def __init__(self,
        *,
        lottery_id: builtins.int = ...,
        lottery_status: builtins.int = ...,
        lottery_mid: builtins.int = ...,
        lottery_time: builtins.int = ...,
        oid: builtins.int = ...,
        type: builtins.int = ...,
        ctime: builtins.int = ...,
        content: typing.Optional[global___Content] = ...,
        member: typing.Optional[global___Member] = ...,
        reply_control: typing.Optional[global___ReplyControl] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["content",b"content","member",b"member","reply_control",b"reply_control"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["content",b"content","ctime",b"ctime","lottery_id",b"lottery_id","lottery_mid",b"lottery_mid","lottery_status",b"lottery_status","lottery_time",b"lottery_time","member",b"member","oid",b"oid","reply_control",b"reply_control","type",b"type"]) -> None: ...
global___Lottery = Lottery

class MainListReply(google.protobuf.message.Message):
    """主评论列表-响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class CallbacksEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: typing.Text
        value: builtins.int
        def __init__(self,
            *,
            key: typing.Text = ...,
            value: builtins.int = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key",b"key","value",b"value"]) -> None: ...

    CURSOR_FIELD_NUMBER: builtins.int
    REPLIES_FIELD_NUMBER: builtins.int
    SUBJECT_CONTROL_FIELD_NUMBER: builtins.int
    UP_TOP_FIELD_NUMBER: builtins.int
    ADMIN_TOP_FIELD_NUMBER: builtins.int
    VOTE_TOP_FIELD_NUMBER: builtins.int
    NOTICE_FIELD_NUMBER: builtins.int
    LOTTERY_FIELD_NUMBER: builtins.int
    ACTIVITY_FIELD_NUMBER: builtins.int
    UP_SELECTION_FIELD_NUMBER: builtins.int
    CM_FIELD_NUMBER: builtins.int
    EFFECTS_FIELD_NUMBER: builtins.int
    OPERATION_FIELD_NUMBER: builtins.int
    TOP_REPLIES_FIELD_NUMBER: builtins.int
    QOE_FIELD_NUMBER: builtins.int
    CALLBACKS_FIELD_NUMBER: builtins.int
    @property
    def cursor(self) -> global___CursorReply:
        """页面游标"""
        pass
    @property
    def replies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ReplyInfo]:
        """评论列表"""
        pass
    @property
    def subject_control(self) -> global___SubjectControl:
        """评论区显示控制字段"""
        pass
    @property
    def up_top(self) -> global___ReplyInfo:
        """UP置顶评论"""
        pass
    @property
    def admin_top(self) -> global___ReplyInfo:
        """管理员置顶评论"""
        pass
    @property
    def vote_top(self) -> global___ReplyInfo:
        """投票置顶评论"""
        pass
    @property
    def notice(self) -> global___Notice:
        """评论区提示"""
        pass
    @property
    def lottery(self) -> global___Lottery:
        """抽奖评论"""
        pass
    @property
    def activity(self) -> global___Activity:
        """活动"""
        pass
    @property
    def up_selection(self) -> global___UpSelection:
        """精选评论区筛选后台信息"""
        pass
    @property
    def cm(self) -> global___CM:
        """广告"""
        pass
    @property
    def effects(self) -> global___Effects:
        """特效"""
        pass
    @property
    def operation(self) -> global___Operation:
        """"""
        pass
    @property
    def top_replies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ReplyInfo]:
        """"""
        pass
    @property
    def qoe(self) -> global___QoeInfo:
        """"""
        pass
    @property
    def callbacks(self) -> google.protobuf.internal.containers.ScalarMap[typing.Text, builtins.int]:
        """"""
        pass
    def __init__(self,
        *,
        cursor: typing.Optional[global___CursorReply] = ...,
        replies: typing.Optional[typing.Iterable[global___ReplyInfo]] = ...,
        subject_control: typing.Optional[global___SubjectControl] = ...,
        up_top: typing.Optional[global___ReplyInfo] = ...,
        admin_top: typing.Optional[global___ReplyInfo] = ...,
        vote_top: typing.Optional[global___ReplyInfo] = ...,
        notice: typing.Optional[global___Notice] = ...,
        lottery: typing.Optional[global___Lottery] = ...,
        activity: typing.Optional[global___Activity] = ...,
        up_selection: typing.Optional[global___UpSelection] = ...,
        cm: typing.Optional[global___CM] = ...,
        effects: typing.Optional[global___Effects] = ...,
        operation: typing.Optional[global___Operation] = ...,
        top_replies: typing.Optional[typing.Iterable[global___ReplyInfo]] = ...,
        qoe: typing.Optional[global___QoeInfo] = ...,
        callbacks: typing.Optional[typing.Mapping[typing.Text, builtins.int]] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["activity",b"activity","admin_top",b"admin_top","cm",b"cm","cursor",b"cursor","effects",b"effects","lottery",b"lottery","notice",b"notice","operation",b"operation","qoe",b"qoe","subject_control",b"subject_control","up_selection",b"up_selection","up_top",b"up_top","vote_top",b"vote_top"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["activity",b"activity","admin_top",b"admin_top","callbacks",b"callbacks","cm",b"cm","cursor",b"cursor","effects",b"effects","lottery",b"lottery","notice",b"notice","operation",b"operation","qoe",b"qoe","replies",b"replies","subject_control",b"subject_control","top_replies",b"top_replies","up_selection",b"up_selection","up_top",b"up_top","vote_top",b"vote_top"]) -> None: ...
global___MainListReply = MainListReply

class MainListReq(google.protobuf.message.Message):
    """主评论列表-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    OID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    CURSOR_FIELD_NUMBER: builtins.int
    EXTRA_FIELD_NUMBER: builtins.int
    AD_EXTRA_FIELD_NUMBER: builtins.int
    RPID_FIELD_NUMBER: builtins.int
    oid: builtins.int
    """目标评论区id"""

    type: builtins.int
    """目标评论区类型"""

    @property
    def cursor(self) -> global___CursorReq:
        """页面游标"""
        pass
    extra: typing.Text
    """扩展数据json"""

    ad_extra: typing.Text
    """广告扩展json"""

    rpid: builtins.int
    """目标评论rpid"""

    def __init__(self,
        *,
        oid: builtins.int = ...,
        type: builtins.int = ...,
        cursor: typing.Optional[global___CursorReq] = ...,
        extra: typing.Text = ...,
        ad_extra: typing.Text = ...,
        rpid: builtins.int = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cursor",b"cursor"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ad_extra",b"ad_extra","cursor",b"cursor","extra",b"extra","oid",b"oid","rpid",b"rpid","type",b"type"]) -> None: ...
global___MainListReq = MainListReq

class Member(google.protobuf.message.Message):
    """用户信息
    *********基础信息*********
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SEX_FIELD_NUMBER: builtins.int
    FACE_FIELD_NUMBER: builtins.int
    LEVEL_FIELD_NUMBER: builtins.int
    OFFICIAL_VERIFY_TYPE_FIELD_NUMBER: builtins.int
    VIP_TYPE_FIELD_NUMBER: builtins.int
    VIP_STATUS_FIELD_NUMBER: builtins.int
    VIP_THEME_TYPE_FIELD_NUMBER: builtins.int
    VIP_LABEL_PATH_FIELD_NUMBER: builtins.int
    GARB_PENDANT_IMAGE_FIELD_NUMBER: builtins.int
    GARB_CARD_IMAGE_FIELD_NUMBER: builtins.int
    GARB_CARD_IMAGE_WITH_FOCUS_FIELD_NUMBER: builtins.int
    GARB_CARD_JUMP_URL_FIELD_NUMBER: builtins.int
    GARB_CARD_NUMBER_FIELD_NUMBER: builtins.int
    GARB_CARD_FAN_COLOR_FIELD_NUMBER: builtins.int
    GARB_CARD_IS_FAN_FIELD_NUMBER: builtins.int
    FANS_MEDAL_NAME_FIELD_NUMBER: builtins.int
    FANS_MEDAL_LEVEL_FIELD_NUMBER: builtins.int
    FANS_MEDAL_COLOR_FIELD_NUMBER: builtins.int
    VIP_NICKNAME_COLOR_FIELD_NUMBER: builtins.int
    VIP_AVATAR_SUBSCRIPT_FIELD_NUMBER: builtins.int
    VIP_LABEL_TEXT_FIELD_NUMBER: builtins.int
    VIP_LABEL_THEME_FIELD_NUMBER: builtins.int
    FANS_MEDAL_COLOR_END_FIELD_NUMBER: builtins.int
    FANS_MEDAL_COLOR_BORDER_FIELD_NUMBER: builtins.int
    FANS_MEDAL_COLOR_NAME_FIELD_NUMBER: builtins.int
    FANS_MEDAL_COLOR_LEVEL_FIELD_NUMBER: builtins.int
    FANS_GUARD_LEVEL_FIELD_NUMBER: builtins.int
    FACE_NFT_FIELD_NUMBER: builtins.int
    FACE_NFT_NEW_FIELD_NUMBER: builtins.int
    IS_SENIOR_MEMBER_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """用户mid"""

    name: typing.Text
    """昵称"""

    sex: typing.Text
    """性别"""

    face: typing.Text
    """头像url"""

    level: builtins.int
    """等级"""

    official_verify_type: builtins.int
    """认证类型
    *********VIP相关*********
    """

    vip_type: builtins.int
    """会员类型
    0:不是大会员 1:月度会员 2:年度大会员
    """

    vip_status: builtins.int
    """会员状态"""

    vip_theme_type: builtins.int
    """会员样式"""

    vip_label_path: typing.Text
    """会员铭牌样式url
    *********装扮相关*********
    """

    garb_pendant_image: typing.Text
    """头像框url"""

    garb_card_image: typing.Text
    """装扮卡url"""

    garb_card_image_with_focus: typing.Text
    """有关注按钮时的装扮卡url"""

    garb_card_jump_url: typing.Text
    """专属装扮页面url"""

    garb_card_number: typing.Text
    """专属装扮id"""

    garb_card_fan_color: typing.Text
    """专属装扮id显示颜色"""

    garb_card_is_fan: builtins.bool
    """是否为专属装扮卡
    *********粉丝勋章相关*********
    """

    fans_medal_name: typing.Text
    """粉丝勋章名"""

    fans_medal_level: builtins.int
    """粉丝勋章等级"""

    fans_medal_color: builtins.int
    """粉丝勋章显示颜色"""

    vip_nickname_color: typing.Text
    """会员昵称颜色"""

    vip_avatar_subscript: builtins.int
    """会员角标
    0:无角标 1:粉色大会员角标 2:绿色小会员角标
    """

    vip_label_text: typing.Text
    """会员标签文"""

    vip_label_theme: typing.Text
    """会员标颜色"""

    fans_medal_color_end: builtins.int
    """"""

    fans_medal_color_border: builtins.int
    """"""

    fans_medal_color_name: builtins.int
    """"""

    fans_medal_color_level: builtins.int
    """"""

    fans_guard_level: builtins.int
    """"""

    face_nft: builtins.int
    """"""

    face_nft_new: builtins.int
    """"""

    is_senior_member: builtins.int
    """"""

    def __init__(self,
        *,
        mid: builtins.int = ...,
        name: typing.Text = ...,
        sex: typing.Text = ...,
        face: typing.Text = ...,
        level: builtins.int = ...,
        official_verify_type: builtins.int = ...,
        vip_type: builtins.int = ...,
        vip_status: builtins.int = ...,
        vip_theme_type: builtins.int = ...,
        vip_label_path: typing.Text = ...,
        garb_pendant_image: typing.Text = ...,
        garb_card_image: typing.Text = ...,
        garb_card_image_with_focus: typing.Text = ...,
        garb_card_jump_url: typing.Text = ...,
        garb_card_number: typing.Text = ...,
        garb_card_fan_color: typing.Text = ...,
        garb_card_is_fan: builtins.bool = ...,
        fans_medal_name: typing.Text = ...,
        fans_medal_level: builtins.int = ...,
        fans_medal_color: builtins.int = ...,
        vip_nickname_color: typing.Text = ...,
        vip_avatar_subscript: builtins.int = ...,
        vip_label_text: typing.Text = ...,
        vip_label_theme: typing.Text = ...,
        fans_medal_color_end: builtins.int = ...,
        fans_medal_color_border: builtins.int = ...,
        fans_medal_color_name: builtins.int = ...,
        fans_medal_color_level: builtins.int = ...,
        fans_guard_level: builtins.int = ...,
        face_nft: builtins.int = ...,
        face_nft_new: builtins.int = ...,
        is_senior_member: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["face",b"face","face_nft",b"face_nft","face_nft_new",b"face_nft_new","fans_guard_level",b"fans_guard_level","fans_medal_color",b"fans_medal_color","fans_medal_color_border",b"fans_medal_color_border","fans_medal_color_end",b"fans_medal_color_end","fans_medal_color_level",b"fans_medal_color_level","fans_medal_color_name",b"fans_medal_color_name","fans_medal_level",b"fans_medal_level","fans_medal_name",b"fans_medal_name","garb_card_fan_color",b"garb_card_fan_color","garb_card_image",b"garb_card_image","garb_card_image_with_focus",b"garb_card_image_with_focus","garb_card_is_fan",b"garb_card_is_fan","garb_card_jump_url",b"garb_card_jump_url","garb_card_number",b"garb_card_number","garb_pendant_image",b"garb_pendant_image","is_senior_member",b"is_senior_member","level",b"level","mid",b"mid","name",b"name","official_verify_type",b"official_verify_type","sex",b"sex","vip_avatar_subscript",b"vip_avatar_subscript","vip_label_path",b"vip_label_path","vip_label_text",b"vip_label_text","vip_label_theme",b"vip_label_theme","vip_nickname_color",b"vip_nickname_color","vip_status",b"vip_status","vip_theme_type",b"vip_theme_type","vip_type",b"vip_type"]) -> None: ...
global___Member = Member

class Notice(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ID_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    LINK_FIELD_NUMBER: builtins.int
    id: builtins.int
    """"""

    content: typing.Text
    """"""

    link: typing.Text
    """"""

    def __init__(self,
        *,
        id: builtins.int = ...,
        content: typing.Text = ...,
        link: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content",b"content","id",b"id","link",b"link"]) -> None: ...
global___Notice = Notice

class Operation(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TYPE_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    SUBTITLE_FIELD_NUMBER: builtins.int
    LINK_FIELD_NUMBER: builtins.int
    REPORT_EXTRA_FIELD_NUMBER: builtins.int
    type: builtins.int
    """"""

    id: builtins.int
    """"""

    @property
    def title(self) -> global___OperationTitle:
        """"""
        pass
    @property
    def subtitle(self) -> global___OperationTitle:
        """"""
        pass
    link: typing.Text
    """"""

    report_extra: typing.Text
    """"""

    def __init__(self,
        *,
        type: builtins.int = ...,
        id: builtins.int = ...,
        title: typing.Optional[global___OperationTitle] = ...,
        subtitle: typing.Optional[global___OperationTitle] = ...,
        link: typing.Text = ...,
        report_extra: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["subtitle",b"subtitle","title",b"title"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id",b"id","link",b"link","report_extra",b"report_extra","subtitle",b"subtitle","title",b"title","type",b"type"]) -> None: ...
global___Operation = Operation

class OperationTitle(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CONTENT_FIELD_NUMBER: builtins.int
    IS_HIGHLIGHT_FIELD_NUMBER: builtins.int
    content: typing.Text
    """"""

    is_highlight: builtins.bool
    """"""

    def __init__(self,
        *,
        content: typing.Text = ...,
        is_highlight: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content",b"content","is_highlight",b"is_highlight"]) -> None: ...
global___OperationTitle = OperationTitle

class PGCVideoSearchItem(google.protobuf.message.Message):
    """PGC视频项目"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TITLE_FIELD_NUMBER: builtins.int
    CATEGORY_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    title: typing.Text
    """标题"""

    category: typing.Text
    """类别"""

    cover: typing.Text
    """封面"""

    def __init__(self,
        *,
        title: typing.Text = ...,
        category: typing.Text = ...,
        cover: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["category",b"category","cover",b"cover","title",b"title"]) -> None: ...
global___PGCVideoSearchItem = PGCVideoSearchItem

class PreviewListReply(google.protobuf.message.Message):
    """评论区预览-回复"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CURSOR_FIELD_NUMBER: builtins.int
    REPLIES_FIELD_NUMBER: builtins.int
    SUBJECT_CONTROL_FIELD_NUMBER: builtins.int
    UPTOP_FIELD_NUMBER: builtins.int
    ADMIN_TOP_FIELD_NUMBER: builtins.int
    VOTE_TOP_FIELD_NUMBER: builtins.int
    @property
    def cursor(self) -> global___CursorReply:
        """页面游标"""
        pass
    @property
    def replies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ReplyInfo]:
        """评论列表"""
        pass
    @property
    def subject_control(self) -> global___SubjectControl:
        """评论区显示控制字段"""
        pass
    @property
    def upTop(self) -> global___ReplyInfo:
        """UP置顶评论"""
        pass
    @property
    def admin_top(self) -> global___ReplyInfo:
        """管理员置顶评论"""
        pass
    @property
    def vote_top(self) -> global___ReplyInfo:
        """投票置顶评论"""
        pass
    def __init__(self,
        *,
        cursor: typing.Optional[global___CursorReply] = ...,
        replies: typing.Optional[typing.Iterable[global___ReplyInfo]] = ...,
        subject_control: typing.Optional[global___SubjectControl] = ...,
        upTop: typing.Optional[global___ReplyInfo] = ...,
        admin_top: typing.Optional[global___ReplyInfo] = ...,
        vote_top: typing.Optional[global___ReplyInfo] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["admin_top",b"admin_top","cursor",b"cursor","subject_control",b"subject_control","upTop",b"upTop","vote_top",b"vote_top"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["admin_top",b"admin_top","cursor",b"cursor","replies",b"replies","subject_control",b"subject_control","upTop",b"upTop","vote_top",b"vote_top"]) -> None: ...
global___PreviewListReply = PreviewListReply

class PreviewListReq(google.protobuf.message.Message):
    """评论区预览-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    OID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    CURSOR_FIELD_NUMBER: builtins.int
    oid: builtins.int
    """目标评论区id"""

    type: builtins.int
    """目标评论区类型"""

    @property
    def cursor(self) -> global___CursorReq:
        """页面游标"""
        pass
    def __init__(self,
        *,
        oid: builtins.int = ...,
        type: builtins.int = ...,
        cursor: typing.Optional[global___CursorReq] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cursor",b"cursor"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cursor",b"cursor","oid",b"oid","type",b"type"]) -> None: ...
global___PreviewListReq = PreviewListReq

class QoeInfo(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    STYLE_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    FEEDBACK_TITLE_FIELD_NUMBER: builtins.int
    SCORE_ITEMS_FIELD_NUMBER: builtins.int
    DISPLAY_RANK_FIELD_NUMBER: builtins.int
    id: builtins.int
    """"""

    type: builtins.int
    """"""

    style: builtins.int
    """"""

    title: typing.Text
    """"""

    feedback_title: typing.Text
    """"""

    @property
    def score_items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___QoeScoreItem]:
        """"""
        pass
    display_rank: builtins.int
    """"""

    def __init__(self,
        *,
        id: builtins.int = ...,
        type: builtins.int = ...,
        style: builtins.int = ...,
        title: typing.Text = ...,
        feedback_title: typing.Text = ...,
        score_items: typing.Optional[typing.Iterable[global___QoeScoreItem]] = ...,
        display_rank: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["display_rank",b"display_rank","feedback_title",b"feedback_title","id",b"id","score_items",b"score_items","style",b"style","title",b"title","type",b"type"]) -> None: ...
global___QoeInfo = QoeInfo

class QoeScoreItem(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TITLE_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    SCORE_FIELD_NUMBER: builtins.int
    title: typing.Text
    """"""

    url: typing.Text
    """"""

    score: builtins.float
    """"""

    def __init__(self,
        *,
        title: typing.Text = ...,
        url: typing.Text = ...,
        score: builtins.float = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["score",b"score","title",b"title","url",b"url"]) -> None: ...
global___QoeScoreItem = QoeScoreItem

class ReplyCardLabel(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TEXT_CONTENT_FIELD_NUMBER: builtins.int
    TEXT_COLOR_DAY_FIELD_NUMBER: builtins.int
    TEXT_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    LABEL_COLOR_DAY_FIELD_NUMBER: builtins.int
    LABEL_COLOR_NIGHT_FIELD_NUMBER: builtins.int
    IMAGE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    BACKGROUND_FIELD_NUMBER: builtins.int
    BACKGROUND_WIDTH_FIELD_NUMBER: builtins.int
    BACKGROUND_HEIGHT_FIELD_NUMBER: builtins.int
    JUMP_URL_FIELD_NUMBER: builtins.int
    text_content: typing.Text
    """"""

    text_color_day: typing.Text
    """"""

    text_color_night: typing.Text
    """"""

    label_color_day: typing.Text
    """"""

    label_color_night: typing.Text
    """"""

    image: typing.Text
    """"""

    type: builtins.int
    """"""

    background: typing.Text
    """"""

    background_width: builtins.float
    """"""

    background_height: builtins.float
    """"""

    jump_url: typing.Text
    """"""

    def __init__(self,
        *,
        text_content: typing.Text = ...,
        text_color_day: typing.Text = ...,
        text_color_night: typing.Text = ...,
        label_color_day: typing.Text = ...,
        label_color_night: typing.Text = ...,
        image: typing.Text = ...,
        type: builtins.int = ...,
        background: typing.Text = ...,
        background_width: builtins.float = ...,
        background_height: builtins.float = ...,
        jump_url: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["background",b"background","background_height",b"background_height","background_width",b"background_width","image",b"image","jump_url",b"jump_url","label_color_day",b"label_color_day","label_color_night",b"label_color_night","text_color_day",b"text_color_day","text_color_night",b"text_color_night","text_content",b"text_content","type",b"type"]) -> None: ...
global___ReplyCardLabel = ReplyCardLabel

class ReplyControl(google.protobuf.message.Message):
    """评论条目控制字段"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ACTION_FIELD_NUMBER: builtins.int
    UP_LIKE_FIELD_NUMBER: builtins.int
    UP_REPLY_FIELD_NUMBER: builtins.int
    SHOW_FOLLOW_BTN_FIELD_NUMBER: builtins.int
    IS_ASSIST_FIELD_NUMBER: builtins.int
    LABEL_TEXT_FIELD_NUMBER: builtins.int
    FOLLOWING_FIELD_NUMBER: builtins.int
    FOLLOWED_FIELD_NUMBER: builtins.int
    BLOCKED_FIELD_NUMBER: builtins.int
    HAS_FOLDED_REPLY_FIELD_NUMBER: builtins.int
    IS_FOLDED_REPLY_FIELD_NUMBER: builtins.int
    IS_UP_TOP_FIELD_NUMBER: builtins.int
    IS_ADMIN_TOP_FIELD_NUMBER: builtins.int
    IS_VOTE_TOP_FIELD_NUMBER: builtins.int
    MAX_LINE_FIELD_NUMBER: builtins.int
    INVISIBLE_FIELD_NUMBER: builtins.int
    IS_CONTRACTOR_FIELD_NUMBER: builtins.int
    IS_NOTE_FIELD_NUMBER: builtins.int
    CARD_LABELS_FIELD_NUMBER: builtins.int
    SUB_REPLY_ENTRY_TEXT_FIELD_NUMBER: builtins.int
    SUB_REPLY_TITLE_TEXT_FIELD_NUMBER: builtins.int
    CONTRACT_DESC_FIELD_NUMBER: builtins.int
    TIME_DESC_FIELD_NUMBER: builtins.int
    BIZ_SCENE_FIELD_NUMBER: builtins.int
    action: builtins.int
    """操作行为标志
    0:无 1:已点赞 2:已点踩
    """

    up_like: builtins.bool
    """是否UP觉得很赞"""

    up_reply: builtins.bool
    """是否存在UP回复"""

    show_follow_btn: builtins.bool
    """是否显示关注按钮"""

    is_assist: builtins.bool
    """是否协管"""

    label_text: typing.Text
    """是否展示标签"""

    following: builtins.bool
    """是否关注"""

    followed: builtins.bool
    """是否粉丝"""

    blocked: builtins.bool
    """是否被自己拉黑"""

    has_folded_reply: builtins.bool
    """是否存在折叠的二级评论"""

    is_folded_reply: builtins.bool
    """是否折叠"""

    is_up_top: builtins.bool
    """是否UP置顶"""

    is_admin_top: builtins.bool
    """是否管理置顶"""

    is_vote_top: builtins.bool
    """是否置顶投票评论"""

    max_line: builtins.int
    """最大收起显示行数"""

    invisible: builtins.bool
    """该条评论可不可见"""

    is_contractor: builtins.bool
    """是否和up签订契约"""

    is_note: builtins.bool
    """是否是笔记评论"""

    @property
    def card_labels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ReplyCardLabel]:
        """"""
        pass
    sub_reply_entry_text: typing.Text
    """"""

    sub_reply_title_text: typing.Text
    """"""

    contract_desc: typing.Text
    """"""

    time_desc: typing.Text
    """"""

    biz_scene: typing.Text
    """"""

    def __init__(self,
        *,
        action: builtins.int = ...,
        up_like: builtins.bool = ...,
        up_reply: builtins.bool = ...,
        show_follow_btn: builtins.bool = ...,
        is_assist: builtins.bool = ...,
        label_text: typing.Text = ...,
        following: builtins.bool = ...,
        followed: builtins.bool = ...,
        blocked: builtins.bool = ...,
        has_folded_reply: builtins.bool = ...,
        is_folded_reply: builtins.bool = ...,
        is_up_top: builtins.bool = ...,
        is_admin_top: builtins.bool = ...,
        is_vote_top: builtins.bool = ...,
        max_line: builtins.int = ...,
        invisible: builtins.bool = ...,
        is_contractor: builtins.bool = ...,
        is_note: builtins.bool = ...,
        card_labels: typing.Optional[typing.Iterable[global___ReplyCardLabel]] = ...,
        sub_reply_entry_text: typing.Text = ...,
        sub_reply_title_text: typing.Text = ...,
        contract_desc: typing.Text = ...,
        time_desc: typing.Text = ...,
        biz_scene: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action",b"action","biz_scene",b"biz_scene","blocked",b"blocked","card_labels",b"card_labels","contract_desc",b"contract_desc","followed",b"followed","following",b"following","has_folded_reply",b"has_folded_reply","invisible",b"invisible","is_admin_top",b"is_admin_top","is_assist",b"is_assist","is_contractor",b"is_contractor","is_folded_reply",b"is_folded_reply","is_note",b"is_note","is_up_top",b"is_up_top","is_vote_top",b"is_vote_top","label_text",b"label_text","max_line",b"max_line","show_follow_btn",b"show_follow_btn","sub_reply_entry_text",b"sub_reply_entry_text","sub_reply_title_text",b"sub_reply_title_text","time_desc",b"time_desc","up_like",b"up_like","up_reply",b"up_reply"]) -> None: ...
global___ReplyControl = ReplyControl

class ReplyExtra(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    SEASON_ID_FIELD_NUMBER: builtins.int
    SEASON_TYPE_FIELD_NUMBER: builtins.int
    EP_ID_FIELD_NUMBER: builtins.int
    IS_STORY_FIELD_NUMBER: builtins.int
    season_id: builtins.int
    """"""

    season_type: builtins.int
    """"""

    ep_id: builtins.int
    """"""

    is_story: builtins.bool
    """"""

    def __init__(self,
        *,
        season_id: builtins.int = ...,
        season_type: builtins.int = ...,
        ep_id: builtins.int = ...,
        is_story: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ep_id",b"ep_id","is_story",b"is_story","season_id",b"season_id","season_type",b"season_type"]) -> None: ...
global___ReplyExtra = ReplyExtra

class ReplyInfo(google.protobuf.message.Message):
    """评论条目信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    REPLIES_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    OID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    ROOT_FIELD_NUMBER: builtins.int
    PARENT_FIELD_NUMBER: builtins.int
    DIALOG_FIELD_NUMBER: builtins.int
    LIKE_FIELD_NUMBER: builtins.int
    CTIME_FIELD_NUMBER: builtins.int
    COUNT_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    REPLY_CONTROL_FIELD_NUMBER: builtins.int
    @property
    def replies(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ReplyInfo]:
        """二级评论列表"""
        pass
    id: builtins.int
    """评论rpid"""

    oid: builtins.int
    """评论区对象id"""

    type: builtins.int
    """评论区类型"""

    mid: builtins.int
    """发布者UID"""

    root: builtins.int
    """根评论rpid"""

    parent: builtins.int
    """父评论rpid"""

    dialog: builtins.int
    """对话评论rpid"""

    like: builtins.int
    """点赞数"""

    ctime: builtins.int
    """发布时间"""

    count: builtins.int
    """回复数"""

    @property
    def content(self) -> global___Content:
        """评论主体信息"""
        pass
    @property
    def member(self) -> global___Member:
        """发布者信息"""
        pass
    @property
    def reply_control(self) -> global___ReplyControl:
        """评论控制字段"""
        pass
    def __init__(self,
        *,
        replies: typing.Optional[typing.Iterable[global___ReplyInfo]] = ...,
        id: builtins.int = ...,
        oid: builtins.int = ...,
        type: builtins.int = ...,
        mid: builtins.int = ...,
        root: builtins.int = ...,
        parent: builtins.int = ...,
        dialog: builtins.int = ...,
        like: builtins.int = ...,
        ctime: builtins.int = ...,
        count: builtins.int = ...,
        content: typing.Optional[global___Content] = ...,
        member: typing.Optional[global___Member] = ...,
        reply_control: typing.Optional[global___ReplyControl] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["content",b"content","member",b"member","reply_control",b"reply_control"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["content",b"content","count",b"count","ctime",b"ctime","dialog",b"dialog","id",b"id","like",b"like","member",b"member","mid",b"mid","oid",b"oid","parent",b"parent","replies",b"replies","reply_control",b"reply_control","root",b"root","type",b"type"]) -> None: ...
global___ReplyInfo = ReplyInfo

class ReplyInfoReply(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    REPLY_FIELD_NUMBER: builtins.int
    @property
    def reply(self) -> global___ReplyInfo:
        """"""
        pass
    def __init__(self,
        *,
        reply: typing.Optional[global___ReplyInfo] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["reply",b"reply"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["reply",b"reply"]) -> None: ...
global___ReplyInfoReply = ReplyInfoReply

class ReplyInfoReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    RPID_FIELD_NUMBER: builtins.int
    SCENE_FIELD_NUMBER: builtins.int
    rpid: builtins.int
    """"""

    scene: builtins.int
    """"""

    def __init__(self,
        *,
        rpid: builtins.int = ...,
        scene: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["rpid",b"rpid","scene",b"scene"]) -> None: ...
global___ReplyInfoReq = ReplyInfoReq

class SearchItem(google.protobuf.message.Message):
    """评论搜索插入项目"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    URL_FIELD_NUMBER: builtins.int
    GOODS_FIELD_NUMBER: builtins.int
    VIDEO_FIELD_NUMBER: builtins.int
    ARTICLE_FIELD_NUMBER: builtins.int
    url: typing.Text
    """"""

    @property
    def goods(self) -> global___GoodsSearchItem:
        """商品"""
        pass
    @property
    def video(self) -> global___VideoSearchItem:
        """视频"""
        pass
    @property
    def article(self) -> global___ArticleSearchItem:
        """专栏"""
        pass
    def __init__(self,
        *,
        url: typing.Text = ...,
        goods: typing.Optional[global___GoodsSearchItem] = ...,
        video: typing.Optional[global___VideoSearchItem] = ...,
        article: typing.Optional[global___ArticleSearchItem] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["article",b"article","goods",b"goods","item",b"item","video",b"video"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["article",b"article","goods",b"goods","item",b"item","url",b"url","video",b"video"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["item",b"item"]) -> typing.Optional[typing_extensions.Literal["goods","video","article"]]: ...
global___SearchItem = SearchItem

class SearchItemCursorReply(google.protobuf.message.Message):
    """评论搜索插入项目响应游标"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    HAS_NEXT_FIELD_NUMBER: builtins.int
    NEXT_FIELD_NUMBER: builtins.int
    has_next: builtins.bool
    """是否有下一页"""

    next: builtins.int
    """下页"""

    def __init__(self,
        *,
        has_next: builtins.bool = ...,
        next: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["has_next",b"has_next","next",b"next"]) -> None: ...
global___SearchItemCursorReply = SearchItemCursorReply

class SearchItemCursorReq(google.protobuf.message.Message):
    """评论搜索插入项目请求游标"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    NEXT_FIELD_NUMBER: builtins.int
    ITEM_TYPE_FIELD_NUMBER: builtins.int
    next: builtins.int
    """下一页"""

    item_type: global___SearchItemType.ValueType
    """tab类型"""

    def __init__(self,
        *,
        next: builtins.int = ...,
        item_type: global___SearchItemType.ValueType = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["item_type",b"item_type","next",b"next"]) -> None: ...
global___SearchItemCursorReq = SearchItemCursorReq

class SearchItemPreHookReply(google.protobuf.message.Message):
    """评论搜索item前置发布-响应"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PLACEHOLDER_TEXT_FIELD_NUMBER: builtins.int
    BACKGROUND_TEXT_FIELD_NUMBER: builtins.int
    ORDERED_TYPE_FIELD_NUMBER: builtins.int
    placeholder_text: typing.Text
    """输入框的文案"""

    background_text: typing.Text
    """背景空白的时候的文案"""

    @property
    def ordered_type(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___SearchItemType.ValueType]:
        """有权限的tab栏的顺序"""
        pass
    def __init__(self,
        *,
        placeholder_text: typing.Text = ...,
        background_text: typing.Text = ...,
        ordered_type: typing.Optional[typing.Iterable[global___SearchItemType.ValueType]] = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["background_text",b"background_text","ordered_type",b"ordered_type","placeholder_text",b"placeholder_text"]) -> None: ...
global___SearchItemPreHookReply = SearchItemPreHookReply

class SearchItemPreHookReq(google.protobuf.message.Message):
    """评论搜索item前置发布-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    OID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    oid: builtins.int
    """目标评论区id"""

    type: builtins.int
    """目标评论区类型"""

    def __init__(self,
        *,
        oid: builtins.int = ...,
        type: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["oid",b"oid","type",b"type"]) -> None: ...
global___SearchItemPreHookReq = SearchItemPreHookReq

class SearchItemReply(google.protobuf.message.Message):
    """评论搜索插入项目-回复"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CURSOR_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    EXTRA_FIELD_NUMBER: builtins.int
    @property
    def cursor(self) -> global___SearchItemCursorReply:
        """"""
        pass
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SearchItem]:
        """搜索的结果"""
        pass
    @property
    def extra(self) -> global___SearchItemReplyExtraInfo:
        """附加信息"""
        pass
    def __init__(self,
        *,
        cursor: typing.Optional[global___SearchItemCursorReply] = ...,
        items: typing.Optional[typing.Iterable[global___SearchItem]] = ...,
        extra: typing.Optional[global___SearchItemReplyExtraInfo] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cursor",b"cursor","extra",b"extra"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cursor",b"cursor","extra",b"extra","items",b"items"]) -> None: ...
global___SearchItemReply = SearchItemReply

class SearchItemReplyExtraInfo(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    EVENT_ID_FIELD_NUMBER: builtins.int
    event_id: typing.Text
    """"""

    def __init__(self,
        *,
        event_id: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["event_id",b"event_id"]) -> None: ...
global___SearchItemReplyExtraInfo = SearchItemReplyExtraInfo

class SearchItemReq(google.protobuf.message.Message):
    """评论搜索插入项目-请求"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    CURSOR_FIELD_NUMBER: builtins.int
    OID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    KEYWORD_FIELD_NUMBER: builtins.int
    @property
    def cursor(self) -> global___SearchItemCursorReq:
        """页面游标"""
        pass
    oid: builtins.int
    """目标评论区id"""

    type: builtins.int
    """评论区类型"""

    keyword: typing.Text
    """搜索关键词"""

    def __init__(self,
        *,
        cursor: typing.Optional[global___SearchItemCursorReq] = ...,
        oid: builtins.int = ...,
        type: builtins.int = ...,
        keyword: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cursor",b"cursor"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cursor",b"cursor","keyword",b"keyword","oid",b"oid","type",b"type"]) -> None: ...
global___SearchItemReq = SearchItemReq

class ShareRepliesInfoReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    OID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    oid: builtins.int
    """"""

    type: builtins.int
    """"""

    def __init__(self,
        *,
        oid: builtins.int = ...,
        type: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["oid",b"oid","type",b"type"]) -> None: ...
global___ShareRepliesInfoReq = ShareRepliesInfoReq

class ShareRepliesInfoResp(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    class ShareExtra(google.protobuf.message.Message):
        """"""
        DESCRIPTOR: google.protobuf.descriptor.Descriptor
        IS_PGC_FIELD_NUMBER: builtins.int
        is_pgc: builtins.bool
        """"""

        def __init__(self,
            *,
            is_pgc: builtins.bool = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["is_pgc",b"is_pgc"]) -> None: ...

    INFOS_FIELD_NUMBER: builtins.int
    FROM_TITLE_FIELD_NUMBER: builtins.int
    FROM_UP_FIELD_NUMBER: builtins.int
    FROM_PIC_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    SLOGAN_PIC_FIELD_NUMBER: builtins.int
    SLOGAN_TEXT_FIELD_NUMBER: builtins.int
    TOPIC_FIELD_NUMBER: builtins.int
    EXTRA_FIELD_NUMBER: builtins.int
    @property
    def infos(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ShareReplyInfo]:
        """"""
        pass
    from_title: typing.Text
    """"""

    from_up: typing.Text
    """"""

    from_pic: typing.Text
    """"""

    url: typing.Text
    """"""

    slogan_pic: typing.Text
    """"""

    slogan_text: typing.Text
    """"""

    @property
    def topic(self) -> global___ShareReplyTopic:
        """"""
        pass
    @property
    def extra(self) -> global___ShareRepliesInfoResp.ShareExtra:
        """"""
        pass
    def __init__(self,
        *,
        infos: typing.Optional[typing.Iterable[global___ShareReplyInfo]] = ...,
        from_title: typing.Text = ...,
        from_up: typing.Text = ...,
        from_pic: typing.Text = ...,
        url: typing.Text = ...,
        slogan_pic: typing.Text = ...,
        slogan_text: typing.Text = ...,
        topic: typing.Optional[global___ShareReplyTopic] = ...,
        extra: typing.Optional[global___ShareRepliesInfoResp.ShareExtra] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["extra",b"extra","topic",b"topic"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["extra",b"extra","from_pic",b"from_pic","from_title",b"from_title","from_up",b"from_up","infos",b"infos","slogan_pic",b"slogan_pic","slogan_text",b"slogan_text","topic",b"topic","url",b"url"]) -> None: ...
global___ShareRepliesInfoResp = ShareRepliesInfoResp

class ShareReplyInfo(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MEMBER_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    SUB_TITLE_FIELD_NUMBER: builtins.int
    ACHIEVEMENT_TEXT_FIELD_NUMBER: builtins.int
    LABEL_URL_FIELD_NUMBER: builtins.int
    @property
    def member(self) -> global___Member:
        """"""
        pass
    @property
    def content(self) -> global___Content:
        """"""
        pass
    title: typing.Text
    """"""

    sub_title: typing.Text
    """"""

    achievement_text: typing.Text
    """"""

    label_url: typing.Text
    """"""

    def __init__(self,
        *,
        member: typing.Optional[global___Member] = ...,
        content: typing.Optional[global___Content] = ...,
        title: typing.Text = ...,
        sub_title: typing.Text = ...,
        achievement_text: typing.Text = ...,
        label_url: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["content",b"content","member",b"member"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["achievement_text",b"achievement_text","content",b"content","label_url",b"label_url","member",b"member","sub_title",b"sub_title","title",b"title"]) -> None: ...
global___ShareReplyInfo = ShareReplyInfo

class ShareReplyTopic(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TOPIC_FIELD_NUMBER: builtins.int
    ORIGIN_TEXT_FIELD_NUMBER: builtins.int
    @property
    def topic(self) -> global___Topic:
        """"""
        pass
    origin_text: typing.Text
    """"""

    def __init__(self,
        *,
        topic: typing.Optional[global___Topic] = ...,
        origin_text: typing.Text = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["topic",b"topic"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["origin_text",b"origin_text","topic",b"topic"]) -> None: ...
global___ShareReplyTopic = ShareReplyTopic

class SubjectControl(google.protobuf.message.Message):
    """评论区控制字段"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    UP_MID_FIELD_NUMBER: builtins.int
    IS_ASSIST_FIELD_NUMBER: builtins.int
    READ_ONLY_FIELD_NUMBER: builtins.int
    HAS_VOTE_ACCESS_FIELD_NUMBER: builtins.int
    HAS_LOTTERY_ACCESS_FIELD_NUMBER: builtins.int
    HAS_FOLDED_REPLY_FIELD_NUMBER: builtins.int
    BG_TEXT_FIELD_NUMBER: builtins.int
    UP_BLOCKED_FIELD_NUMBER: builtins.int
    HAS_ACTIVITY_ACCESS_FIELD_NUMBER: builtins.int
    SHOW_TITLE_FIELD_NUMBER: builtins.int
    SHOW_UP_ACTION_FIELD_NUMBER: builtins.int
    SWITCHER_TYPE_FIELD_NUMBER: builtins.int
    INPUT_DISABLE_FIELD_NUMBER: builtins.int
    ROOT_TEXT_FIELD_NUMBER: builtins.int
    CHILD_TEXT_FIELD_NUMBER: builtins.int
    COUNT_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    GIVEUP_TEXT_FIELD_NUMBER: builtins.int
    HAS_NOTE_ACCESS_FIELD_NUMBER: builtins.int
    DISABLE_JUMP_EMOTE_FIELD_NUMBER: builtins.int
    up_mid: builtins.int
    """UP主mid"""

    is_assist: builtins.bool
    """自己是否为协管"""

    read_only: builtins.bool
    """是否只读"""

    has_vote_access: builtins.bool
    """是否有发起投票权限"""

    has_lottery_access: builtins.bool
    """是否有发起抽奖权限"""

    has_folded_reply: builtins.bool
    """是否有被折叠评论"""

    bg_text: typing.Text
    """空评论区背景文案"""

    up_blocked: builtins.bool
    """是否被UP拉黑"""

    has_activity_access: builtins.bool
    """是否有发起活动权限"""

    show_title: builtins.bool
    """标题展示控制"""

    show_up_action: builtins.bool
    """是否显示UP主操作标志"""

    switcher_type: builtins.int
    """是否显示评论区排序切换按钮"""

    input_disable: builtins.bool
    """是否禁止输入框"""

    root_text: typing.Text
    """根评论输入框背景文案"""

    child_text: typing.Text
    """子评论输入框背景文案"""

    count: builtins.int
    """评论总数"""

    title: typing.Text
    """评论区标题"""

    giveup_text: typing.Text
    """离开态输入框的文案"""

    has_note_access: builtins.bool
    """"""

    disable_jump_emote: builtins.bool
    """"""

    def __init__(self,
        *,
        up_mid: builtins.int = ...,
        is_assist: builtins.bool = ...,
        read_only: builtins.bool = ...,
        has_vote_access: builtins.bool = ...,
        has_lottery_access: builtins.bool = ...,
        has_folded_reply: builtins.bool = ...,
        bg_text: typing.Text = ...,
        up_blocked: builtins.bool = ...,
        has_activity_access: builtins.bool = ...,
        show_title: builtins.bool = ...,
        show_up_action: builtins.bool = ...,
        switcher_type: builtins.int = ...,
        input_disable: builtins.bool = ...,
        root_text: typing.Text = ...,
        child_text: typing.Text = ...,
        count: builtins.int = ...,
        title: typing.Text = ...,
        giveup_text: typing.Text = ...,
        has_note_access: builtins.bool = ...,
        disable_jump_emote: builtins.bool = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bg_text",b"bg_text","child_text",b"child_text","count",b"count","disable_jump_emote",b"disable_jump_emote","giveup_text",b"giveup_text","has_activity_access",b"has_activity_access","has_folded_reply",b"has_folded_reply","has_lottery_access",b"has_lottery_access","has_note_access",b"has_note_access","has_vote_access",b"has_vote_access","input_disable",b"input_disable","is_assist",b"is_assist","read_only",b"read_only","root_text",b"root_text","show_title",b"show_title","show_up_action",b"show_up_action","switcher_type",b"switcher_type","title",b"title","up_blocked",b"up_blocked","up_mid",b"up_mid"]) -> None: ...
global___SubjectControl = SubjectControl

class Topic(google.protobuf.message.Message):
    """话题项"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    LINK_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    link: typing.Text
    """跳转url"""

    id: builtins.int
    """话题id"""

    def __init__(self,
        *,
        link: typing.Text = ...,
        id: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id",b"id","link",b"link"]) -> None: ...
global___Topic = Topic

class UGCVideoSearchItem(google.protobuf.message.Message):
    """UGC视频项目"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TITLE_FIELD_NUMBER: builtins.int
    UP_NICKNAME_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    COVER_FIELD_NUMBER: builtins.int
    title: typing.Text
    """标题"""

    up_nickname: typing.Text
    """UP主昵称"""

    duration: builtins.int
    """时长(单位为秒)"""

    cover: typing.Text
    """封面"""

    def __init__(self,
        *,
        title: typing.Text = ...,
        up_nickname: typing.Text = ...,
        duration: builtins.int = ...,
        cover: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cover",b"cover","duration",b"duration","title",b"title","up_nickname",b"up_nickname"]) -> None: ...
global___UGCVideoSearchItem = UGCVideoSearchItem

class UpSelection(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    PENDING_COUNT_FIELD_NUMBER: builtins.int
    IGNORE_COUNT_FIELD_NUMBER: builtins.int
    pending_count: builtins.int
    """待审评论数"""

    ignore_count: builtins.int
    """忽略评论数"""

    def __init__(self,
        *,
        pending_count: builtins.int = ...,
        ignore_count: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ignore_count",b"ignore_count","pending_count",b"pending_count"]) -> None: ...
global___UpSelection = UpSelection

class Url(google.protobuf.message.Message):
    """超链项"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TITLE_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    PREFIX_ICON_FIELD_NUMBER: builtins.int
    APP_URL_SCHEMA_FIELD_NUMBER: builtins.int
    APP_NAME_FIELD_NUMBER: builtins.int
    APP_PACKAGE_NAME_FIELD_NUMBER: builtins.int
    CLICK_REPORT_FIELD_NUMBER: builtins.int
    IS_HALF_SCREEN_FIELD_NUMBER: builtins.int
    EXPOSURE_REPORT_FIELD_NUMBER: builtins.int
    title: typing.Text
    """标题"""

    state: builtins.int
    """"""

    prefix_icon: typing.Text
    """图标url"""

    app_url_schema: typing.Text
    """"""

    app_name: typing.Text
    """"""

    app_package_name: typing.Text
    """"""

    click_report: typing.Text
    """上报id"""

    is_half_screen: builtins.bool
    """"""

    exposure_report: typing.Text
    """"""

    def __init__(self,
        *,
        title: typing.Text = ...,
        state: builtins.int = ...,
        prefix_icon: typing.Text = ...,
        app_url_schema: typing.Text = ...,
        app_name: typing.Text = ...,
        app_package_name: typing.Text = ...,
        click_report: typing.Text = ...,
        is_half_screen: builtins.bool = ...,
        exposure_report: typing.Text = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["app_name",b"app_name","app_package_name",b"app_package_name","app_url_schema",b"app_url_schema","click_report",b"click_report","exposure_report",b"exposure_report","is_half_screen",b"is_half_screen","prefix_icon",b"prefix_icon","state",b"state","title",b"title"]) -> None: ...
global___Url = Url

class UserCallbackReply(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    def __init__(self,
        ) -> None: ...
global___UserCallbackReply = UserCallbackReply

class UserCallbackReq(google.protobuf.message.Message):
    """"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    MID_FIELD_NUMBER: builtins.int
    SCENE_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    OID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """"""

    scene: global___UserCallbackScene.ValueType
    """"""

    action: global___UserCallbackAction.ValueType
    """"""

    oid: builtins.int
    """"""

    type: builtins.int
    """"""

    def __init__(self,
        *,
        mid: builtins.int = ...,
        scene: global___UserCallbackScene.ValueType = ...,
        action: global___UserCallbackAction.ValueType = ...,
        oid: builtins.int = ...,
        type: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action",b"action","mid",b"mid","oid",b"oid","scene",b"scene","type",b"type"]) -> None: ...
global___UserCallbackReq = UserCallbackReq

class VideoSearchItem(google.protobuf.message.Message):
    """视频项目"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    TYPE_FIELD_NUMBER: builtins.int
    UGC_FIELD_NUMBER: builtins.int
    PGC_FIELD_NUMBER: builtins.int
    type: global___SearchItemVideoSubType.ValueType
    """"""

    @property
    def ugc(self) -> global___UGCVideoSearchItem:
        """UGC视频"""
        pass
    @property
    def pgc(self) -> global___PGCVideoSearchItem:
        """PGC视频"""
        pass
    def __init__(self,
        *,
        type: global___SearchItemVideoSubType.ValueType = ...,
        ugc: typing.Optional[global___UGCVideoSearchItem] = ...,
        pgc: typing.Optional[global___PGCVideoSearchItem] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pgc",b"pgc","ugc",b"ugc","video_item",b"video_item"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pgc",b"pgc","type",b"type","ugc",b"ugc","video_item",b"video_item"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions.Literal["video_item",b"video_item"]) -> typing.Optional[typing_extensions.Literal["ugc","pgc"]]: ...
global___VideoSearchItem = VideoSearchItem

class Vote(google.protobuf.message.Message):
    """投票信息"""
    DESCRIPTOR: google.protobuf.descriptor.Descriptor
    ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    COUNT_FIELD_NUMBER: builtins.int
    id: builtins.int
    """投票id"""

    title: typing.Text
    """投票标题"""

    count: builtins.int
    """参与人数"""

    def __init__(self,
        *,
        id: builtins.int = ...,
        title: typing.Text = ...,
        count: builtins.int = ...,
        ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["count",b"count","id",b"id","title",b"title"]) -> None: ...
global___Vote = Vote
